@@ -112,7 +112,7 @@ function() {
       graphics::legend("topleft", 
                        legend = rev(KTSEnv$tsToPlotNames), 
                        lty = 1,lwd <- rev(KTSEnv$linWs), 
-                       bty = "n", ncol = 4, 
+                       bty = "n", ncol = 4, cex = KTSEnv$labSis,
                        col = rev(KTSEnv$CoLoRs), y.intersp = 1)
       
     }
@@ -226,19 +226,27 @@ function() {
           filename <- paste0("fig",sample(10000:99999, 1),".tiff")
         }
         KTSEnv$filename <- filename
-  
+        
         winW <- verifyIntEntry(tcltk::tclvalue(entryVar2), noValid = NA)
+        
         if(is.na(winW)){
-          winW <- 1500
+          winW <- 15
         }
         KTSEnv$winW <- winW     
         
         winH <- verifyIntEntry(tcltk::tclvalue(entryVar3), noValid = NA)
         if(is.na(winH)){
-          winH <- 500
+          winH <- 15
         }
         KTSEnv$winH <- winH
         
+        
+        resIm <- verifyIntEntry(tcltk::tclvalue(entryVar4), noValid = NA)
+        if(is.na(resIm)){
+          resIm <- 300
+        }
+        KTSEnv$resIm <- resIm
+        
         tcltk::tkdestroy(KTSEnv$newWin)
         
       }
@@ -248,27 +256,36 @@ function() {
       
       entryVar1 <- tcltk::tclVar("")
       ent1 <-tcltk2::tk2entry(KTSEnv$newWin, width = "25",
-                             textvariable = entryVar1)
+                              textvariable = entryVar1)
       text1 <- "File name"
       lab1 <- tcltk2::tk2label(KTSEnv$newWin,
-                              text = text1,
-                              justify = "left")
+                               text = text1,
+                               justify = "left")
       
       entryVar2 <- tcltk::tclVar("")
       ent2 <-tcltk2::tk2entry(KTSEnv$newWin, width = "25",
-                             textvariable = entryVar2)
-      text2 <- "Width (pixels)"
+                              textvariable = entryVar2)
+      text2 <- "Width (cm)"
       lab2 <- tcltk2::tk2label(KTSEnv$newWin,
-                              text = text2,
-                              justify = "left")
+                               text = text2,
+                               justify = "left")
       
       entryVar3 <- tcltk::tclVar("")
       ent3 <-tcltk2::tk2entry(KTSEnv$newWin, width = "25",
-                             textvariable = entryVar3)
-      text3 <- "Height (pixels)"
+                              textvariable = entryVar3)
+      text3 <- "Height (cm)"
       lab3 <- tcltk2::tk2label(KTSEnv$newWin,
-                              text = text3,
-                              justify = "left")
+                               text = text3,
+                               justify = "left")
+      
+      
+      entryVar4 <- tcltk::tclVar("")
+      ent4 <-tcltk2::tk2entry(KTSEnv$newWin, width = "25",
+                              textvariable = entryVar4)
+      text4 <- "Resolution (ppi)"
+      lab4 <- tcltk2::tk2label(KTSEnv$newWin,
+                               text = text4,
+                               justify = "left")
       
       tcltk::tkgrid(lab1,padx = 10, pady = c(15, 5), sticky = "w")
       tcltk::tkgrid(ent1, padx = 10, pady = c(0, 15))
@@ -276,15 +293,18 @@ function() {
       tcltk::tkgrid(ent2, padx = 10, pady = c(0, 15))
       tcltk::tkgrid(lab3,padx = 10, pady = c(15, 5), sticky = "w")
       tcltk::tkgrid(ent3, padx = 10, pady = c(0, 15))
+      tcltk::tkgrid(lab4,padx = 10, pady = c(15, 5), sticky = "w")
+      tcltk::tkgrid(ent4, padx = 10, pady = c(0, 15))
       
       OKbutton <-tcltk::tkbutton(KTSEnv$newWin, text = "OK",
                                  width = -6, command = onOK)
       tcltk::tkgrid(OKbutton, padx = 10, pady = c(5, 15))
-      tcltk::tkbind(ent3, "<Return>", onOK)
+      tcltk::tkbind(ent4, "<Return>", onOK)
       tcltk::tkfocus(KTSEnv$newWin)
       
     }
     
+    
     savePopUp()
     tcltk::tkwait.window(KTSEnv$newWin)
     exten <- getExtension(KTSEnv$filename)
@@ -295,13 +315,15 @@ function() {
     
     if( exten == "tiff"){
       
-      grDevices::tiff(filename = KTSEnv$filename,units = "px",
-                      width = KTSEnv$winW, height = KTSEnv$winH)
+      grDevices::png(filename = KTSEnv$filename,units = "cm",
+                      width = KTSEnv$winW, height = KTSEnv$winH,
+                      res = KTSEnv$resIm)
       
     }else{
       
-      grDevices::png(filename = KTSEnv$filename,units = "px",
-                     width = KTSEnv$winW, height = KTSEnv$winH) 
+      grDevices::png(filename = KTSEnv$filename,units = "cm",
+                     width = KTSEnv$winW, height = KTSEnv$winH,
+                     res = KTSEnv$resIm) 
       
     }
     
@@ -349,7 +371,7 @@ function() {
     graphics::legend("topleft", 
                      legend = rev(KTSEnv$tsToPlotNames), 
                      lty = 1,lwd <- rev(KTSEnv$linWs), 
-                     bty = "n", ncol = 4, 
+                     bty = "n", ncol = 4, cex = KTSEnv$labSis,
                      col = rev(KTSEnv$CoLoRs), y.intersp = 1)
     
 
@@ -412,7 +434,7 @@ function() {
     graphics::legend("topleft", 
                      legend = rev(KTSEnv$tsToPlotNames), 
                      lty = 1,lwd <- rev(KTSEnv$linWs), 
-                     bty = "n", ncol = 4, 
+                     bty = "n", ncol = 4, cex = KTSEnv$labSis,
                      col = rev(KTSEnv$CoLoRs), y.intersp = 1)
     
     parPlotSize <- graphics::par("plt")
